==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/uk.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Управління Параметри Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "управління Галерея");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Повнорозмірні Ширина зображення");
define('MANAGE_GALLERY_FULL_HEIGHT', "збільшити Висота");
define('MANAGE_GALLERY_THUMB_WIDTH', "Ескіз Ширина зображення");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Ескіз Висота зображення");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Заповідник Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Показати Назви");
define('MANAGE_GALLERY_DISABLE_SORT', "відключити Сортувати");
define('MANAGE_GALLERY_DELETE_IMAGE', "видалити зображення");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "зберегти сортування");
define('MANAGE_GALLERY_PUBLISH_MSG', "Натисніть кнопку &quot;Оновити&quot;, щоб опублікувати <br /> завантажені вами зображення.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Всі зображення були змінені і налаштування були збережені.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Був помилка зміни розміру зображення або збереження налаштувань.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Ваш образ (и) був завантажений.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Був Помилка при завантаженні зображення (и).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Файл, який ви намагаєтеся завантажити, не є зображенням.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Файл, який ви намагаєтеся завантажити занадто великий.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Назва було збережено.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ви впевнені, що хочете видалити зображення");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Зображення було видалено.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Був помилка видалення зображення.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Збереження параметрів і зміна розмірів зображень, будь ласка, зачекайте ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Завантаження, зачекайте будь ласка ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Порядок сортування не був збережений. Ви хочете, щоб зберегти порядок сортування?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Порядок сортування зображень збережений.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Був помилка при збереженні роду зображення.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/uk.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Управління Параметри Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "управління Галерея");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Повнорозмірні Ширина зображення");
define('MANAGE_GALLERY_FULL_HEIGHT', "збільшити Висота");
define('MANAGE_GALLERY_THUMB_WIDTH', "Ескіз Ширина зображення");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Ескіз Висота зображення");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Заповідник Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Показати Назви");
define('MANAGE_GALLERY_DISABLE_SORT', "відключити Сортувати");
define('MANAGE_GALLERY_DELETE_IMAGE', "видалити зображення");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "зберегти сортування");
define('MANAGE_GALLERY_PUBLISH_MSG', "Натисніть кнопку &quot;Оновити&quot;, щоб опублікувати <br /> завантажені вами зображення.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Всі зображення були змінені і налаштування були збережені.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Був помилка зміни розміру зображення або збереження налаштувань.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Ваш образ (и) був завантажений.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Був Помилка при завантаженні зображення (и).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Файл, який ви намагаєтеся завантажити, не є зображенням.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Файл, який ви намагаєтеся завантажити занадто великий.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Назва було збережено.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ви впевнені, що хочете видалити зображення");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Зображення було видалено.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Був помилка видалення зображення.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Збереження параметрів і зміна розмірів зображень, будь ласка, зачекайте ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Завантаження, зачекайте будь ласка ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Порядок сортування не був збережений. Ви хочете, щоб зберегти порядок сортування?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Порядок сортування зображень збережений.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Був помилка при збереженні роду зображення.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Файл, який ви намагаєтеся завантажити, більший, ніж параметри PHP &quot;upload_max_filesize&quot; або &quot;post_max_size&quot;. Зверніться до системного адміністратора, щоб збільшити ці обмеження.");
?>
